#!/usr/bin/env node
/*!
 * gitmars v4.0.0-alpha.1
 * 这是一个git工作流工具
 * (c) 2021-2022 saqqdy<https://github.com/saqqdy> 
 * Released under the MIT License.
 */
'use strict';

const { program } = require("commander");
const sh = require("shelljs");
const { green, yellow } = require("chalk");
const inquirer = require("inquirer");
const getGitRevParse = require("@gitmars/core/lib/git/getGitRevParse");
const getIsGitProject = require("@gitmars/core/lib/git/getIsGitProject");
const { removeFile } = require("@gitmars/core/lib/utils/file");
const { createArgs } = require("@gitmars/core/lib/utils/command");
const { cleanCache } = require("@gitmars/core/lib/cache/cache");
const { cleanPkgInfo } = require("@gitmars/core/lib/utils/pkgInfo");
const { cleanBuildConfig } = require("@gitmars/core/lib/build/buildConfig");
const { options, args } = require("./conf/clean");
const { gitDir } = getGitRevParse();
const i18n = require("./locales");
sh.config.silent = true;
program.name("gitm clean").usage("[-f --force]").description("\u6E05\u7406gitmars\u7F13\u5B58");
if (args.length > 0)
  program.arguments(createArgs(args));
options.forEach((o) => {
  program.option(o.flags, o.description, o.defaultValue);
});
program.action(async (opt) => {
  if (getIsGitProject()) {
    if (opt.force) {
      await inquirer.prompt({
        type: "confirm",
        name: "value",
        message: i18n.__(
          "You have entered --force, which will also clear the gitmars execution cache. Should I continue?"
        ),
        default: false
      }).then((answers) => {
        if (!answers.value) {
          sh.echo(green("\u5DF2\u9000\u51FA"));
          process.exit(0);
        }
      });
      removeFile([
        {
          name: i18n.__("gitmars command queue cache file"),
          url: gitDir + "/.gitmarscommands"
        },
        {
          name: i18n.__("gitmars execution log file"),
          url: gitDir + "/.gitmarslog"
        }
      ]);
    }
  } else {
    sh.echo(
      yellow(
        i18n.__("The current directory is not a git project directory")
      )
    );
  }
  cleanBuildConfig();
  cleanPkgInfo();
  cleanCache();
});
program.parse(process.argv);
