#!/usr/bin/env node
/*!
 * gitmars v4.0.0-alpha.1
 * 这是一个git工作流工具
 * (c) 2021-2022 saqqdy<https://github.com/saqqdy> 
 * Released under the MIT License.
 */
'use strict';

const { program } = require("commander");
const sh = require("shelljs");
const { green, red } = require("chalk");
const getIsGitProject = require("@gitmars/core/lib/git/getIsGitProject");
const getGitRevParse = require("@gitmars/core/lib/git/getGitRevParse");
const { writeFile } = require("@gitmars/core/lib/utils/file");
const getConfig = require("@gitmars/core/lib/getConfig");
const { defaults } = require("./common/global");
const i18n = require("./locales");
if (!getIsGitProject()) {
  sh.echo(
    red(i18n.__("The current directory is not a git project directory"))
  );
  process.exit(1);
}
const config = getConfig();
program.name("gitm config").usage("<option> [value]").command("set <option> [value]").description(i18n.__("Set configuration items for gitmars")).action(async (option, value) => {
  let { filepath } = config;
  if (!filepath) {
    const { root } = getGitRevParse();
    filepath = root + "/.gitmarsrc";
  }
  if (value) {
    if (Object.keys(defaults).includes(option)) {
      config[option] = value;
      delete config.filepath;
      delete config.skipCI;
      await writeFile(filepath, JSON.stringify(config, null, 4));
      sh.echo(green("\u4FDD\u5B58\u6210\u529F"));
      process.exit(0);
    } else {
      sh.echo(red("\u4E0D\u652F\u6301" + option + "\u8FD9\u4E2A\u914D\u7F6E\u9879"));
      process.exit(1);
    }
  } else {
    sh.echo(i18n.__("Please enter the items to be configured"));
    process.exit(1);
  }
});
program.name("gitm config").usage("list [option]").command("list [option]").description(i18n.__("Query single or all gitmars for configuration items")).action((option) => {
  if (option) {
    sh.echo(green(config[option]));
  } else {
    sh.echo(green(config));
  }
  process.exit(0);
});
program.parse(process.argv);
