#!/usr/bin/env node
/*!
 * gitmars v4.0.0-alpha.1
 * 这是一个git工作流工具
 * (c) 2021-2022 saqqdy<https://github.com/saqqdy> 
 * Released under the MIT License.
 */
'use strict';

const { program } = require("commander");
const sh = require("shelljs");
const { green, yellow, red } = require("chalk");
const inquirer = require("inquirer");
const { queue } = require("@gitmars/core/lib/queue");
const {
  getCommandCache,
  cleanCommandCache
} = require("@gitmars/core/lib/cache/commandCache");
const getIsGitProject = require("@gitmars/core/lib/git/getIsGitProject");
const getGitStatus = require("@gitmars/core/lib/git/getGitStatus");
const { createArgs } = require("@gitmars/core/lib/utils/command");
const { options, args } = require("./conf/continue");
const i18n = require("./locales");
if (!getIsGitProject()) {
  sh.echo(
    red(i18n.__("The current directory is not a git project directory"))
  );
  process.exit(1);
}
program.name("gitm continue").usage("[-l --list]").description(i18n.__("Continue unfinished operations"));
if (args.length > 0)
  program.arguments(createArgs(args));
options.forEach((o) => {
  program.option(o.flags, o.description, o.defaultValue);
});
program.action(async (opt) => {
  const sum = getGitStatus();
  const cmd = getCommandCache();
  if (opt.list) {
    sh.echo(cmd);
    process.exit(0);
  }
  if (cmd.length > 0) {
    if (sum.A.length > 0 || sum.D.length > 0 || sum.M.length > 0 || sum.UU.length > 0) {
      await inquirer.prompt({
        type: "confirm",
        name: "value",
        message: i18n.__(
          "A conflict has been detected in the merge branch and you need to run git add . Do you want to force the script to continue?"
        ),
        default: false
      }).then((answers) => {
        if (!answers.value) {
          sh.echo(green("\u5DF2\u9000\u51FA"));
          process.exit(0);
        }
      });
    } else if (sum["??"].length > 0) {
      sh.echo(
        yellow(
          i18n.__(
            "An uncommitted file was detected, please be aware!"
          )
        )
      );
    }
    queue(cmd).then(() => {
      cleanCommandCache();
    });
  } else {
    sh.echo(red(i18n.__("There are no unexecuted commands in the queue")));
  }
});
program.parse(process.argv);
