#!/usr/bin/env node
/*!
 * gitmars v4.0.0-alpha.1
 * 这是一个git工作流工具
 * (c) 2021-2022 saqqdy<https://github.com/saqqdy> 
 * Released under the MIT License.
 */
'use strict';

const { program } = require("commander");
const sh = require("shelljs");
const { green, red } = require("chalk");
const inquirer = require("inquirer");
const getProperty = require("js-cool/lib/getProperty");
const getCurrentBranch = require("@gitmars/core/lib/git/getCurrentBranch");
const { createArgs } = require("@gitmars/core/lib/utils/command");
const commands = require("./go/index");
const { options, args } = require("./conf/go");
const i18n = require("./locales");
program.name("gitm go").usage("[command]").description(
  i18n.__("Intelligent guessing of the action you want to perform")
);
if (args.length > 0)
  program.arguments(createArgs(args));
options.forEach((o) => {
  program.option(o.flags, o.description, o.defaultValue);
});
program.action(async (command) => {
  const current = getCurrentBranch();
  sh.echo(green(`\u5F53\u524D\u5206\u652F${current}\uFF0C\u7CFB\u7EDF\u731C\u6D4B\u4F60\u53EF\u80FD\u60F3\u505A\u4EE5\u4E0B\u64CD\u4F5C\uFF1A`));
  if (command) {
    const cmd = getProperty(commands, command);
    if (!cmd) {
      sh.echo(
        red(
          i18n.__(
            "The command you entered was not found and may not be supported at this time"
          )
        )
      );
      process.exit(1);
    }
    cmd();
  } else {
    inquirer.prompt({
      type: "list",
      name: "command",
      message: i18n.__("Please select the operation you want?"),
      default: "combine",
      choices: [
        new inquirer.Separator(
          " === 1. " + i18n.__("Gitmars Workflow") + " === "
        ),
        "combine",
        "end",
        "update",
        "build",
        "start",
        "undo",
        "redo",
        "admin.publish",
        "admin.update",
        "admin.create",
        "admin.clean",
        new inquirer.Separator(
          " === 2. " + i18n.__("Advanced Tools") + " === "
        ),
        "branch",
        "copy",
        "get",
        "save",
        "cleanbranch",
        "clean",
        "revert",
        "link",
        "unlink",
        "postmsg",
        new inquirer.Separator(" === " + i18n.__("Exit") + " === "),
        "exit",
        new inquirer.Separator()
      ],
      filter: (val) => {
        return val;
      }
    }).then((answers) => {
      if (answers.command === "exit") {
        sh.echo(green("\u5DF2\u9000\u51FA"));
        process.exit(0);
      }
      sh.echo(green(`\u4F60\u9009\u62E9\u4E86${answers.command}\u6307\u4EE4`));
      getProperty(commands, answers.command)();
    });
  }
});
program.parse(process.argv);
