#!/usr/bin/env node
/*!
 * gitmars v4.0.0-alpha.1
 * 这是一个git工作流工具
 * (c) 2021-2022 saqqdy<https://github.com/saqqdy> 
 * Released under the MIT License.
 */
'use strict';

const { program } = require("commander");
const dayjs = require("dayjs");
const columnify = require("columnify");
const { red, green, cyan, blue, yellow } = require("chalk");
const getIsGitProject = require("@gitmars/core/lib/git/getIsGitProject");
const getGitLogs = require("@gitmars/core/lib/git/getGitLogs");
const { createArgs } = require("@gitmars/core/lib/utils/command");
const echo = require("@gitmars/core/lib/utils/echo");
const { options, args } = require("./conf/log");
const i18n = require("./locales");
if (!getIsGitProject()) {
  echo(red(i18n.__("The current directory is not a git project directory")));
  process.exit(1);
}
program.name("gitm log").usage(
  "[branch] [--lastet [lastet]] [--limit [limit]] [--no-merges] [--json]"
).description(i18n.__("Log query"));
if (args.length > 0)
  program.arguments(createArgs(args));
options.forEach((o) => {
  program.option(o.flags, o.description, o.defaultValue);
});
program.action(async (branch, opt) => {
  const logs = getGitLogs({
    lastet: opt.lastet,
    limit: opt.limit,
    branch,
    noMerges: !opt.merges
  });
  if (opt.json) {
    console.info(logs);
  } else {
    const data = logs.map((log) => ({
      commit: cyan(log["%h"]),
      merge: cyan(log["%p"]),
      title: green(log["%s"]),
      author: yellow(log["%an"]),
      date: blue(dayjs(log["%aI"]).format("YYYY/MM/DD HH:mm:ss"))
    }));
    echo(columnify(data));
  }
  process.exit(0);
});
program.parse(process.argv);
