#!/usr/bin/env node
/*!
 * gitmars v4.0.0-alpha.1
 * 这是一个git工作流工具
 * (c) 2021-2022 saqqdy<https://github.com/saqqdy> 
 * Released under the MIT License.
 */
'use strict';

const { program } = require("commander");
const sh = require("shelljs");
const { red } = require("chalk");
const { queue } = require("@gitmars/core/lib/queue");
const getIsGitProject = require("@gitmars/core/lib/git/getIsGitProject");
const i18n = require("./locales");
if (!getIsGitProject()) {
  sh.echo(
    red(i18n.__("The current directory is not a git project directory"))
  );
  process.exit(1);
}
program.name("gitm merge").usage("<name>").arguments("<name>").description(i18n.__("Merge branch code")).action((name) => {
  const cmd = [
    {
      cmd: `git merge --no-ff ${name}`,
      config: {
        again: false,
        success: `\u5408\u5E76${name}\u5206\u652F\u6210\u529F`,
        fail: `\u5408\u5E76${name}\u5206\u652F\u51FA\u9519\u4E86\uFF0C\u8BF7\u6839\u636E\u63D0\u793A\u5904\u7406`
      }
    },
    {
      cmd: "git push",
      config: {
        again: true,
        success: i18n.__("Successful Pushed"),
        fail: i18n.__("Push failed, please follow the prompts")
      }
    }
  ];
  queue(cmd);
});
program.parse(process.argv);
