#!/usr/bin/env node
/*!
 * gitmars v4.0.0-alpha.1
 * 这是一个git工作流工具
 * (c) 2021-2022 saqqdy<https://github.com/saqqdy> 
 * Released under the MIT License.
 */
'use strict';

const { program } = require("commander");
const sh = require("shelljs");
const { red } = require("chalk");
const { queue } = require("@gitmars/core/lib/queue");
const getIsGitProject = require("@gitmars/core/lib/git/getIsGitProject");
const getCurrentBranch = require("@gitmars/core/lib/git/getCurrentBranch");
const { createArgs } = require("@gitmars/core/lib/utils/command");
const { options, args } = require("./conf/save");
const i18n = require("./locales");
if (!getIsGitProject()) {
  sh.echo(
    red(i18n.__("The current directory is not a git project directory"))
  );
  process.exit(1);
}
program.name("gitm save").usage("[message] [-f --force]").description(i18n.__("Staging current branch files"));
if (args.length > 0)
  program.arguments(createArgs(args));
options.forEach((o) => {
  program.option(o.flags, o.description, o.defaultValue);
});
program.action((message, opt) => {
  if (!message)
    message = getCurrentBranch();
  message = `${message}_cache_by_gitmars`;
  let cmd = [
    {
      cmd: `git stash save "${message}"`,
      config: {
        success: i18n.__("File staging successful"),
        fail: "\u51FA\u9519\u4E86\uFF0C\u8BF7\u8054\u7CFB\u7BA1\u7406\u5458"
      }
    }
  ];
  if (opt.force) {
    cmd = [
      "git add .",
      {
        cmd: `git stash save "${message}"`,
        config: {
          success: i18n.__("File staging successful"),
          fail: "\u51FA\u9519\u4E86\uFF0C\u8BF7\u8054\u7CFB\u7BA1\u7406\u5458"
        }
      }
    ];
  }
  queue(cmd);
});
program.parse(process.argv);
