#!/usr/bin/env node
/*!
 * gitmars v4.0.0-alpha.1
 * 这是一个git工作流工具
 * (c) 2021-2022 saqqdy<https://github.com/saqqdy> 
 * Released under the MIT License.
 */
'use strict';

const { program } = require("commander");
const sh = require("shelljs");
const { createArgs } = require("@gitmars/core/lib/utils/command");
const { spawnSync } = require("@gitmars/core/lib/spawn");
const { options, args } = require("./conf/unlink");
const i18n = require("./locales");
program.name("gitm unlink").usage("[name]").description("\u89E3\u9664\u672C\u5730\u5305\u94FE\u63A5");
if (args.length > 0)
  program.arguments(createArgs(args));
options.forEach((o) => {
  program.option(o.flags, o.description, o.defaultValue);
});
program.action((name) => {
  const isLink = sh.test("-L", `./node_modules/${name}`);
  const isExist = sh.test("-e", `./node_modules/${name}_bak`);
  const npmClient = sh.which("yarn") ? "yarn" : "npm";
  if (!name) {
    spawnSync(npmClient, ["unlink"]);
    sh.echo("\u5904\u7406\u5B8C\u6210");
    process.exit(0);
  } else if (isLink) {
    spawnSync(npmClient, ["unlink", name]);
  } else {
    sh.echo(
      i18n.__(
        "No softlink found, please confirm entering the correct name"
      )
    );
  }
  if (isExist) {
    sh.mv(`./node_modules/${name}_bak`, `./node_modules/${name}`);
  }
  sh.echo("\u5904\u7406\u5B8C\u6210");
});
program.parse(process.argv);
